@@ -233,21 +233,6 @@ namespace gum {
     /// @return Returns a string representation of this IBayesNet.
     std::string toString() const;
 
-    /***
-     * @return the minimal subset of soids that conditions the target
-     *
-     * i.e. P(target| soids)=P(target|@return)
-     */
-    NodeSet minimalCondSet(NodeId target, const NodeSet& soids) const;
-
-
-    /***
-     * @return the minimal subset of soids that conditions the targets
-     *
-     * i.e. P(targets| soids)=P(targets|@return)
-     */
-    NodeSet minimalCondSet(const NodeSet& targets, const NodeSet& soids) const;
-
     /**
      * @return a Tensor for a (numerical) discrete variable representing an evidence with a float
      * as observed value
@@ -279,18 +264,6 @@ namespace gum {
      * @return the size in bytes
      */
     Size memoryFootprint() const;
-
-    private:
-    void _minimalCondSetVisitUp_(NodeId         node,
-                                 const NodeSet& soids,
-                                 NodeSet&       minimal,
-                                 NodeSet&       alreadyVisitedUp,
-                                 NodeSet&       alreadyVisitedDn) const;
-    void _minimalCondSetVisitDn_(NodeId         node,
-                                 const NodeSet& soids,
-                                 NodeSet&       minimal,
-                                 NodeSet&       alreadyVisitedUp,
-                                 NodeSet&       alreadyVisitedDn) const;
   };
 
 
