@@ -588,6 +588,6 @@ namespace gum {
 
 #ifndef GUM_NO_INLINE
 #  include <agrum/BN/learning/structureUtils/graphChange_inl.h>
-#endif   // GUM_NOINLINE
+#endif   // GU%_NO_INLINE
 
 #endif   /* GUM_LEARNING_GRAPH_CHANGE_H */
