@@ -364,6 +364,6 @@ namespace gum {
 
 #ifndef GUM_NO_INLINE
 #  include <agrum/base/graphs/algorithms/DAGCycleDetector_inl.h>
-#endif   // GUM_NOINLINE
+#endif   // GU%_NO_INLINE
 
 #endif   // GUM_DAG_CYCLE_DETECTOR_H
