@@ -341,7 +341,7 @@ namespace gum {
 
 #ifndef GUM_NO_INLINE
 #  include <agrum/base/graphs/parts/arcGraphPart_inl.h>
-#endif   // GUM_NOINLINE
+#endif   // GU%_NO_INLINE
 
 #include <agrum/base/graphs/parts/arcGraphPart_tpl.h>
 
