@@ -131,6 +131,6 @@ namespace gum {
 
 #ifndef GUM_NO_INLINE
 #  include <agrum/base/graphs/parts/listeners/undiGraphListener_inl.h>
-#endif   // GUM_NOINLINE
+#endif   // GU%_NO_INLINE
 
 #endif   // GUM_UNDIGRAPH_LISTENER_H
