@@ -71,7 +71,7 @@ namespace gum {
      * its parents.
      */
     template < typename GUM_SCALAR >
-    class Amplitude: public MultiDimAggregator< GUM_SCALAR > {
+    class Amplitude final: public MultiDimAggregator< GUM_SCALAR > {
       public:
       Amplitude();
 
