@@ -71,7 +71,7 @@ namespace gum {
      * variable since only 0 and 1 indexes are adressed...
      */
     template < typename GUM_SCALAR >
-    class And: public MultiDimAggregator< GUM_SCALAR > {
+    class And final: public MultiDimAggregator< GUM_SCALAR > {
       public:
       And();
       And(const And< GUM_SCALAR >& from);
